Deployment API Reference
------------------------

.. toctree::
   :maxdepth: 3

The Freva deployment Class
==========================

.. automodule:: freva_deployment.deploy
   :members:
   :undoc-members:
   :show-inheritance:

The Deployment Text User Interface
==================================

.. automodule:: freva_deployment.ui.deployment_tui.main_window
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: freva_deployment.ui.deployment_tui.base
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: freva_deployment.ui.deployment_tui.deploy_forms
   :members:
   :undoc-members:
   :show-inheritance:
